/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
export interface BandingProperties {
    /**
     * The color of the first row or column. If this field is set, the first row or column is filled with this color and the colors alternate between firstBandColor and secondBandColor starting from the second row or column. Otherwise, the first row or column is filled with firstBandColor and the colors proceed to alternate as they normally would.
     */
    headerColor: Color;
    /**
     * The color of the first row or column. If this field is set, the first row or column is filled with this color and the colors alternate between firstBandColor and secondBandColor starting from the second row or column. Otherwise, the first row or column is filled with firstBandColor and the colors proceed to alternate as they normally would. If headerColor is also set, this field takes precedence.
     */
    headerColorStyle: ColorStyle;
    /**
     * The first color that is alternating. (Required)
     */
    firstBandColor: Color;
    /**
     * The first color that is alternating. (Required) If firstBandColor is also set, this field takes precedence.
     */
    firstBandColorStyle: ColorStyle;
    /**
     * The second color that is alternating. (Required)
     */
    secondBandColor: Color;
    /**
     * The second color that is alternating. (Required) If secondBandColor is also set, this field takes precedence.
     */
    secondBandColorStyle: ColorStyle;
    /**
     * The color of the last row or column. If this field is not set, the last row or column is filled with either firstBandColor or secondBandColor , depending on the color of the previous row or column.
     */
    footerColor: Color;
    /**
     * The color of the last row or column. If this field is not set, the last row or column is filled with either firstBandColor or secondBandColor , depending on the color of the previous row or column. If footerColor is also set, this field takes precedence.
     */
    footerColorStyle: ColorStyle;
}
//# sourceMappingURL=BandingProperties.d.ts.map