/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { TextFormat } from './TextFormat';
import { TextPosition } from './TextPosition';
export interface BaselineValueFormat {
    /**
     * The comparison type of key value with baseline value.
     ** COMPARISON_TYPE_UNDEFINED - Default value, do not use.
     ** ABSOLUTE_DIFFERENCE - Use absolute difference between key and baseline value.
     ** PERCENTAGE_DIFFERENCE - Use percentage difference between key and baseline value.
     */
    comparisonType: 'COMPARISON_TYPE_UNDEFINED' | 'ABSOLUTE_DIFFERENCE' | 'PERCENTAGE_DIFFERENCE';
    /**
     * Text formatting options for baseline value.
     */
    textFormat: TextFormat;
    /**
     * Specifies the horizontal text positioning of baseline value. This field is optional. If not specified, default positioning is used.
     */
    position?: TextPosition;
    /**
     * Description which is appended after the baseline value. This field is optional.
     */
    description?: string;
    /**
     * Color to be used, in case baseline value represents a positive change for key value. This field is optional.
     */
    positiveColor?: Color;
    /**
     * Color to be used, in case baseline value represents a positive change for key value. This field is optional. If positiveColor is also set, this field takes precedence.
     */
    positiveColorStyle?: ColorStyle;
    /**
     * Color to be used, in case baseline value represents a negative change for key value. This field is optional.
     */
    negativeColor?: Color;
    /**
     * Color to be used, in case baseline value represents a negative change for key value. This field is optional. If negativeColor is also set, this field takes precedence.
     */
    negativeColorStyle?: ColorStyle;
}
//# sourceMappingURL=BaselineValueFormat.d.ts.map