/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartAxisViewWindowOptions } from './ChartAxisViewWindowOptions';
import { TextFormat } from './TextFormat';
import { TextPosition } from './TextPosition';
export interface BasicChartAxis {
    /**
     * The position of this axis.
     ** BASIC_CHART_AXIS_POSITION_UNSPECIFIED - Default value, do not use.
     ** BOTTOM_AXIS - The axis rendered at the bottom of a chart. For most charts, this is the standard major axis. For bar charts, this is a minor axis.
     ** LEFT_AXIS - The axis rendered at the left of a chart. For most charts, this is a minor axis. For bar charts, this is the standard major axis.
     ** RIGHT_AXIS - The axis rendered at the right of a chart. For most charts, this is a minor axis. For bar charts, this is an unusual major axis.
     */
    position: 'BASIC_CHART_AXIS_POSITION_UNSPECIFIED' | 'BOTTOM_AXIS' | 'LEFT_AXIS' | 'RIGHT_AXIS';
    /**
     * The title of this axis. If set, this overrides any title inferred from headers of the data.
     */
    title: string;
    /**
     * The format of the title. Only valid if the axis is not associated with the domain.
     */
    format: TextFormat;
    /**
     * The axis title text position.
     */
    titleTextPosition: TextPosition;
    /**
     * The view window options for this axis.
     */
    viewWindowOptions: ChartAxisViewWindowOptions;
}
//# sourceMappingURL=BasicChartAxis.d.ts.map