/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BasicSeriesDataPointStyleOverride } from './BasicSeriesDataPointStyleOverride';
import { ChartData } from './ChartData';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { DataLabel } from './DataLabel';
import { LineStyle } from './LineStyle';
import { PointStyle } from './PointStyle';
export interface BasicChartSeries {
    /**
     * The data being visualized in this chart series.
     */
    series: ChartData;
    /**
     * The minor axis that will specify the range of values for this series. For example, if charting stocks over time, the 'Volume' series may want to be pinned to the right with the prices pinned to the left, because the scale of trading volume is different than the scale of prices. It is an error to specify an axis that isn't a valid minor axis for the chart's type.
     ** BASIC_CHART_AXIS_POSITION_UNSPECIFIED - Default value, do not use.
     ** BOTTOM_AXIS - The axis rendered at the bottom of a chart. For most charts, this is the standard major axis. For bar charts, this is a minor axis.
     ** LEFT_AXIS - The axis rendered at the left of a chart. For most charts, this is a minor axis. For bar charts, this is the standard major axis.
     ** RIGHT_AXIS - The axis rendered at the right of a chart. For most charts, this is a minor axis. For bar charts, this is an unusual major axis.
     */
    targetAxis: 'BASIC_CHART_AXIS_POSITION_UNSPECIFIED' | 'BOTTOM_AXIS' | 'LEFT_AXIS' | 'RIGHT_AXIS';
    /**
     * The type of this series. Valid only if the chartType is COMBO . Different types will change the way the series is visualized. Only LINE , AREA , and COLUMN are supported.
     ** BASIC_CHART_TYPE_UNSPECIFIED - Default value, do not use.
     ** BAR - A bar chart .
     ** LINE - A line chart .
     ** AREA - An area chart .
     ** COLUMN - A column chart .
     ** SCATTER - A scatter chart .
     ** COMBO - A combo chart .
     ** STEPPED_AREA - A stepped area chart .
     */
    type: 'BASIC_CHART_TYPE_UNSPECIFIED' | 'BAR' | 'LINE' | 'AREA' | 'COLUMN' | 'SCATTER' | 'COMBO' | 'STEPPED_AREA';
    /**
     * The line style of this series. Valid only if the chartType is AREA , LINE , or SCATTER . COMBO charts are also supported if the series chart type is AREA or LINE.
     */
    lineStyle: LineStyle;
    /**
     * Information about the data labels for this series.
     */
    dataLabel: DataLabel;
    /**
     * The color for elements (such as bars, lines, and points) associated with this series. If empty, a default color is used.
     */
    color: Color;
    /**
     * The color for elements (such as bars, lines, and points) associated with this series. If empty, a default color is used. If color is also set, this field takes precedence.
     */
    colorStyle: ColorStyle;
    /**
     * The style for points associated with this series. Valid only if the chartType is AREA , LINE , or SCATTER . COMBO charts are also supported if the series chart type is AREA , LINE , or SCATTER . If empty, a default point style is used.
     */
    pointStyle: PointStyle;
    /**
     * Style override settings for series data points.
     */
    styleOverrides: BasicSeriesDataPointStyleOverride[];
}
//# sourceMappingURL=BasicChartSeries.d.ts.map