/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BasicChartAxis } from './BasicChartAxis';
import { BasicChartDomain } from './BasicChartDomain';
import { BasicChartSeries } from './BasicChartSeries';
import { DataLabel } from './DataLabel';
export interface BasicChartSpec {
    /**
     * The type of the chart.
     ** BASIC_CHART_TYPE_UNSPECIFIED - Default value, do not use.
     ** BAR - A bar chart .
     ** LINE - A line chart .
     ** AREA - An area chart .
     ** COLUMN - A column chart .
     ** SCATTER - A scatter chart .
     ** COMBO - A combo chart .
     ** STEPPED_AREA - A stepped area chart .
     */
    chartType: 'BASIC_CHART_TYPE_UNSPECIFIED' | 'BAR' | 'LINE' | 'AREA' | 'COLUMN' | 'SCATTER' | 'COMBO' | 'STEPPED_AREA';
    /**
     * The position of the chart legend.
     ** BASIC_CHART_LEGEND_POSITION_UNSPECIFIED - Default value, do not use.
     ** BOTTOM_LEGEND - The legend is rendered on the bottom of the chart.
     ** LEFT_LEGEND - The legend is rendered on the left of the chart.
     ** RIGHT_LEGEND - The legend is rendered on the right of the chart.
     ** TOP_LEGEND - The legend is rendered on the top of the chart.
     ** NO_LEGEND - No legend is rendered.
     */
    legendPosition: 'BASIC_CHART_LEGEND_POSITION_UNSPECIFIED' | 'BOTTOM_LEGEND' | 'LEFT_LEGEND' | 'RIGHT_LEGEND' | 'TOP_LEGEND' | 'NO_LEGEND';
    /**
     * The axis on the chart.
     */
    axis: BasicChartAxis[];
    /**
     * The domain of data this is charting. Only a single domain is supported.
     */
    domains: BasicChartDomain[];
    /**
     * The data this chart is visualizing.
     */
    series: BasicChartSeries[];
    /**
     * The number of rows or columns in the data that are 'headers'. If not set, Google Sheets will guess how many rows are headers based on the data.
     *
     * (Note that BasicChartAxis.title may override the axis title inferred from the header values.)
     */
    headerCount: number;
    /**
     * True to make the chart 3D. Applies to Bar and Column charts.
     */
    threeDimensional: boolean;
    /**
     * If some values in a series are missing, gaps may appear in the chart (e.g, segments of lines in a line chart will be missing). To eliminate these gaps set this to true. Applies to Line, Area, and Combo charts.
     */
    interpolateNulls: boolean;
    /**
     * The stacked type for charts that support vertical stacking. Applies to Area, Bar, Column, Combo, and Stepped Area charts.
     ** BASIC_CHART_STACKED_TYPE_UNSPECIFIED - Default value, do not use.
     ** NOT_STACKED - Series are not stacked.
     ** STACKED - Series values are stacked, each value is rendered vertically beginning from the top of the value below it.
     ** PERCENT_STACKED - Vertical stacks are stretched to reach the top of the chart, with values laid out as percentages of each other.
     */
    stackedType: 'BASIC_CHART_STACKED_TYPE_UNSPECIFIED' | 'NOT_STACKED' | 'STACKED' | 'PERCENT_STACKED';
    /**
     * Gets whether all lines should be rendered smooth or straight by default. Applies to Line charts.
     */
    lineSmoothing: boolean;
    /**
     * The behavior of tooltips and data highlighting when hovering on data and chart area.
     ** BASIC_CHART_COMPARE_MODE_UNSPECIFIED - Default value, do not use.
     ** DATUM - Only the focused data element is highlighted and shown in the tooltip.
     ** CATEGORY - All data elements with the same category (e.g., domain value) are highlighted and shown in the tooltip.
     */
    compareMode: 'BASIC_CHART_COMPARE_MODE_UNSPECIFIED' | 'DATUM' | 'CATEGORY';
    /**
     * Controls whether to display additional data labels on stacked charts which sum the total value of all stacked values at each value along the domain axis. These data labels can only be set when chartType is one of AREA , BAR , COLUMN , COMBO or STEPPED_AREA and stackedType is either STACKED or PERCENT_STACKED . In addition, for COMBO , this will only be supported if there is only one type of stackable series type or one type has more series than the others and each of the other types have no more than one series. For example, if a chart has two stacked bar series and one area series, the total data labels will be supported. If it has three bar series and two area series, total data labels are not allowed. Neither CUSTOM nor placement can be set on the totalDataLabel.
     */
    totalDataLabel: DataLabel;
}
//# sourceMappingURL=BasicChartSpec.d.ts.map