/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartData } from './ChartData';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { TextFormat } from './TextFormat';
export interface BubbleChartSpec {
    /**
     * Where the legend of the chart should be drawn.
     ** BUBBLE_CHART_LEGEND_POSITION_UNSPECIFIED - Default value, do not use.
     ** BOTTOM_LEGEND - The legend is rendered on the bottom of the chart.
     ** LEFT_LEGEND - The legend is rendered on the left of the chart.
     ** RIGHT_LEGEND - The legend is rendered on the right of the chart.
     ** TOP_LEGEND - The legend is rendered on the top of the chart.
     ** NO_LEGEND - No legend is rendered.
     ** INSIDE_LEGEND - The legend is rendered inside the chart area.
     */
    legendPosition: 'BUBBLE_CHART_LEGEND_POSITION_UNSPECIFIED' | 'BOTTOM_LEGEND' | 'LEFT_LEGEND' | 'RIGHT_LEGEND' | 'TOP_LEGEND' | 'NO_LEGEND' | 'INSIDE_LEGEND';
    /**
     * The data containing the bubble labels. These do not need to be unique.
     */
    bubbleLabels: ChartData;
    /**
     * The data containing the bubble x-values. These values locate the bubbles in the chart horizontally.
     */
    domain: ChartData;
    /**
     * The data contianing the bubble y-values. These values locate the bubbles in the chart vertically.
     */
    series: ChartData;
    /**
     * The data containing the bubble group IDs. All bubbles with the same group ID are drawn in the same color. If bubbleSizes is specified then this field must also be specified but may contain blank values. This field is optional.
     */
    groupIds?: ChartData;
    /**
     * The data contianing the bubble sizes. Bubble sizes are used to draw the bubbles at different sizes relative to each other. If specified, groupIds must also be specified. This field is optional.
     */
    bubbleSizes?: ChartData;
    /**
     * The opacity of the bubbles between 0 and 1.0. 0 is fully transparent and 1 is fully opaque.
     */
    bubbleOpacity: number;
    /**
     * The bubble border color.
     */
    bubbleBorderColor: Color;
    /**
     * The bubble border color. If bubbleBorderColor is also set, this field takes precedence.
     */
    bubbleBorderColorStyle: ColorStyle;
    /**
     * The max radius size of the bubbles, in pixels. If specified, the field must be a positive value.
     */
    bubbleMaxRadiusSize: number;
    /**
     * The minimum radius size of the bubbles, in pixels. If specific, the field must be a positive value.
     */
    bubbleMinRadiusSize: number;
    /**
     * The format of the text inside the bubbles. Strikethrough and underline are not supported.
     */
    bubbleTextStyle: TextFormat;
}
//# sourceMappingURL=BubbleChartSpec.d.ts.map