/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Borders } from './Borders';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { NumberFormat } from './NumberFormat';
import { Padding } from './Padding';
import { TextFormat } from './TextFormat';
import { TextRotation } from './TextRotation';
export interface CellFormat {
    /**
     * A format describing how number values should be represented to the user.
     */
    numberFormat?: NumberFormat;
    /**
     * The background color of the cell.
     */
    backgroundColor?: Color;
    /**
     * The background color of the cell. If backgroundColor is also set, this field takes precedence.
     */
    backgroundColorStyle: ColorStyle;
    /**
     * The borders of the cell.
     */
    borders?: Borders;
    /**
     * The padding of the cell.
     */
    padding: Padding;
    /**
     * The horizontal alignment of the value in the cell.
     ** HORIZONTAL_ALIGN_UNSPECIFIED - The horizontal alignment is not specified. Do not use this.
     ** LEFT - The text is explicitly aligned to the left of the cell.
     ** CENTER - The text is explicitly aligned to the center of the cell.
     ** RIGHT - The text is explicitly aligned to the right of the cell.
     */
    horizontalAlignment?: 'HORIZONTAL_ALIGN_UNSPECIFIED' | 'LEFT' | 'CENTER' | 'RIGHT';
    /**
     * The vertical alignment of the value in the cell.
     ** VERTICAL_ALIGN_UNSPECIFIED - The vertical alignment is not specified. Do not use this.
     ** TOP - The text is explicitly aligned to the top of the cell.
     ** MIDDLE - The text is explicitly aligned to the middle of the cell.
     ** BOTTOM - The text is explicitly aligned to the bottom of the cell.
     */
    verticalAlignment?: 'VERTICAL_ALIGN_UNSPECIFIED' | 'TOP' | 'MIDDLE' | 'BOTTOM';
    /**
     * The wrap strategy for the value in the cell.
     ** WRAP_STRATEGY_UNSPECIFIED - The default value, do not use.
     ** OVERFLOW_CELL - Lines that are longer than the cell width will be written in the next cell over, so long as that cell is empty. If the next cell over is non-empty, this behaves the same as CLIP . The text will never wrap to the next line unless the user manually inserts a new line.
     ** LEGACY_WRAP - This wrap strategy represents the old Google Sheets wrap strategy where words that are longer than a line are clipped rather than broken. This strategy is not supported on all platforms and is being phased out.
     ** CLIP - Lines that are longer than the cell width will be clipped. The text will never wrap to the next line unless the user manually inserts a new line.
     ** WRAP - Words that are longer than a line are wrapped at the character level rather than clipped.
     */
    wrapStrategy?: 'WRAP_STRATEGY_UNSPECIFIED' | 'OVERFLOW_CELL' | 'LEGACY_WRAP' | 'CLIP' | 'WRAP';
    /**
     * The direction of the text in the cell.
     ** TEXT_DIRECTION_UNSPECIFIED - The text direction is not specified. Do not use this.
     ** LEFT_TO_RIGHT - The text direction of left-to-right was set by the user.
     ** RIGHT_TO_LEFT - The text direction of right-to-left was set by the user.
     */
    textDirection?: 'TEXT_DIRECTION_UNSPECIFIED' | 'LEFT_TO_RIGHT' | 'RIGHT_TO_LEFT';
    /**
     * The format of the text in the cell (unless overridden by a format run).
     */
    textFormat: TextFormat;
    /**
     * How a hyperlink, if it exists, should be displayed in the cell.
     ** HYPERLINK_DISPLAY_TYPE_UNSPECIFIED - The default value: the hyperlink is rendered. Do not use this.
     ** LINKED - A hyperlink should be explicitly rendered.
     ** PLAIN_TEXT - A hyperlink should not be rendered.
     */
    hyperlinkDisplayType?: 'HYPERLINK_DISPLAY_TYPE_UNSPECIFIED' | 'LINKED' | 'PLAIN_TEXT';
    /**
     * The rotation applied to text in a cell.
     */
    textRotation: TextRotation;
}
//# sourceMappingURL=CellFormat.d.ts.map