/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartGroupRule } from './ChartGroupRule';
import { ChartSourceRange } from './ChartSourceRange';
import { DataSourceColumnReference } from './DataSourceColumnReference';
export declare type ChartData = ChartDataWithRange | ChartDataWithReference;
interface ChartDataCommons {
    /**
     * The rule to group the data by if the ChartData backs the domain of a data source chart. Only supported for data source charts.
     */
    groupRule: ChartGroupRule;
    /**
     * The aggregation type for the series of a data source chart. Only supported for data source charts.
     ** CHART_AGGREGATE_TYPE_UNSPECIFIED - Default value, do not use.
     ** AVERAGE - Average aggregate function.
     ** COUNT - Count aggregate function.
     ** MAX - Maximum aggregate function.
     ** MEDIAN - Median aggregate function.
     ** MIN - Minimum aggregate function.
     ** SUM - Sum aggregate function.
     */
    aggregateType: 'CHART_AGGREGATE_TYPE_UNSPECIFIED' | 'AVERAGE' | 'COUNT' | 'MAX' | 'MEDIAN' | 'MIN' | 'SUM';
}
interface ChartDataWithRange extends ChartDataCommons {
    /**
     * The source ranges of the data.
     */
    sourceRange: ChartSourceRange;
}
interface ChartDataWithReference extends ChartDataCommons {
    /**
     * The reference to the data source column that the data reads from.
     */
    columnReference: DataSourceColumnReference;
}
export {};
//# sourceMappingURL=ChartData.d.ts.map