/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BasicChartSpec } from './BasicChartSpec';
import { BubbleChartSpec } from './BubbleChartSpec';
import { CandlestickChartSpec } from './CandlestickChartSpec';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { DataSourceChartProperties } from './DataSourceChartProperties';
import { FilterSpec } from './FilterSpec';
import { HistogramChartSpec } from './HistogramChartSpec';
import { OrgChartSpec } from './OrgChartSpec';
import { PieChartSpec } from './PieChartSpec';
import { ScorecardChartSpec } from './ScorecardChartSpec';
import { SortSpec } from './SortSpec';
import { TextFormat } from './TextFormat';
import { TextPosition } from './TextPosition';
import { TreemapChartSpec } from './TreemapChartSpec';
import { WaterfallChartSpec } from './WaterfallChartSpec';
export declare type ChartSpec = ChartSpecWithBasicChart | ChartSpecWithPieChart | ChartSpecWithBubbleChart | ChartSpecWithCandlestickChart | ChartSpecWithOrgChart | ChartSpecWithHistogramChart | ChartSpecWithWaterfallChart | ChartSpecWithTreemapChart | ChartSpecWithScorecardChart;
interface ChartSpecCommons {
    /**
     * The title of the chart.
     */
    title: string;
    /**
     * The alternative text that describes the chart. This is often used for accessibility.
     */
    altText: string;
    /**
     * The title text format. Strikethrough and underline are not supported.
     */
    titleTextFormat: TextFormat;
    /**
     * The title text position. This field is optional.
     */
    titleTextPosition?: TextPosition;
    /**
     * The subtitle of the chart.
     */
    subtitle: string;
    /**
     * The subtitle text format. Strikethrough and underline are not supported.
     */
    subtitleTextFormat: TextFormat;
    /**
     * The subtitle text position. This field is optional.
     */
    subtitleTextPosition?: TextPosition;
    /**
     * The name of the font to use by default for all chart text (e.g. title, axis labels, legend). If a font is specified for a specific part of the chart it will override this font name.
     */
    fontName: string;
    /**
     * True to make a chart fill the entire space in which it's rendered with minimum padding. False to use the default padding. (Not applicable to Geo and Org charts.)
     */
    maximized: boolean;
    /**
     * The background color of the entire chart. Not applicable to Org charts.
     */
    backgroundColor: Color;
    /**
     * The background color of the entire chart. Not applicable to Org charts. If backgroundColor is also set, this field takes precedence.
     */
    backgroundColorStyle: ColorStyle;
    /**
     * If present, the field contains data source chart specific properties.
     */
    dataSourceChartProperties: DataSourceChartProperties;
    /**
     * The filters applied to the source data of the chart. Only supported for data source charts.
     */
    filterSpecs: FilterSpec[];
    /**
     * The order to sort the chart data by. Only a single sort spec is supported. Only supported for data source charts.
     */
    sortSpecs: SortSpec[];
    /**
     * Determines how the charts will use hidden rows or columns.
     ** CHART_HIDDEN_DIMENSION_STRATEGY_UNSPECIFIED - Default value, do not use.
     ** SKIP_HIDDEN_ROWS_AND_COLUMNS - Charts will skip hidden rows and columns.
     ** SKIP_HIDDEN_ROWS - Charts will skip hidden rows only.
     ** SKIP_HIDDEN_COLUMNS - Charts will skip hidden columns only.
     ** SHOW_ALL - Charts will not skip any hidden rows or columns.
     */
    hiddenDimensionStrategy: 'CHART_HIDDEN_DIMENSION_STRATEGY_UNSPECIFIED' | 'SKIP_HIDDEN_ROWS_AND_COLUMNS' | 'SKIP_HIDDEN_ROWS' | 'SKIP_HIDDEN_COLUMNS' | 'SHOW_ALL';
}
interface ChartSpecWithBasicChart extends ChartSpecCommons {
    /**
     * A basic chart specification, can be one of many kinds of charts. See BasicChartType for the list of all charts this supports.
     */
    basicChart: BasicChartSpec;
}
interface ChartSpecWithPieChart extends ChartSpecCommons {
    /**
     * A pie chart specification.
     */
    pieChart: PieChartSpec;
}
interface ChartSpecWithBubbleChart extends ChartSpecCommons {
    /**
     * A bubble chart specification.
     */
    bubbleChart: BubbleChartSpec;
}
interface ChartSpecWithCandlestickChart extends ChartSpecCommons {
    /**
     * A candlestick chart specification.
     */
    candlestickChart: CandlestickChartSpec;
}
interface ChartSpecWithOrgChart extends ChartSpecCommons {
    /**
     * An org chart specification.
     */
    orgChart: OrgChartSpec;
}
interface ChartSpecWithHistogramChart extends ChartSpecCommons {
    /**
     * A histogram chart specification.
     */
    histogramChart: HistogramChartSpec;
}
interface ChartSpecWithWaterfallChart extends ChartSpecCommons {
    /**
     * A waterfall chart specification.
     */
    waterfallChart: WaterfallChartSpec;
}
interface ChartSpecWithTreemapChart extends ChartSpecCommons {
    /**
     * A treemap chart specification.
     */
    treemapChart: TreemapChartSpec;
}
interface ChartSpecWithScorecardChart extends ChartSpecCommons {
    /**
     * A scorecard chart specification.
     */
    scorecardChart: ScorecardChartSpec;
}
export {};
//# sourceMappingURL=ChartSpec.d.ts.map