/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
export interface DataExecutionStatus {
    /**
     * The state of the data execution.
     ** DATA_EXECUTION_STATE_UNSPECIFIED - Default value, do not use.
     ** NOT_STARTED - The data execution has not started.
     ** RUNNING - The data execution has started and is running.
     ** SUCCEEDED - The data execution has completed successfully.
     ** FAILED - The data execution has completed with errors.
     */
    state: 'DATA_EXECUTION_STATE_UNSPECIFIED' | 'NOT_STARTED' | 'RUNNING' | 'SUCCEEDED' | 'FAILED';
    /**
     * The error code.
     ** DATA_EXECUTION_ERROR_CODE_UNSPECIFIED - Default value, do not use.
     ** TIMED_OUT - The data execution timed out.
     ** TOO_MANY_ROWS - The data execution returns more rows than the limit.
     ** TOO_MANY_CELLS - The data execution returns more cells than the limit.
     ** ENGINE - Error is received from the backend data execution engine (e.g. BigQuery). Check errorMessage for details.
     ** PARAMETER_INVALID - One or some of the provided data source parameters are invalid.
     ** UNSUPPORTED_DATA_TYPE - The data execution returns an unsupported data type.
     ** DUPLICATE_COLUMN_NAMES - The data execution returns duplicate column names or aliases.
     ** INTERRUPTED - The data execution is interrupted. Please refresh later.
     ** CONCURRENT_QUERY - The data execution is currently in progress, can not be refreshed until it completes.
     ** OTHER - Other errors.
     ** TOO_MANY_CHARS_PER_CELL - The data execution returns values that exceed the maximum characters allowed in a single cell.
     ** DATA_NOT_FOUND - The database referenced by the data source is not found.
     ** PERMISSION_DENIED - The user does not have access to the database referenced by the data source.
     ** MISSING_COLUMN_ALIAS - The data execution returns columns with missing aliases.
     ** OBJECT_NOT_FOUND - The data source object does not exist.
     ** OBJECT_IN_ERROR_STATE - The data source object is currently in error state. To force refresh, set force in RefreshDataSourceRequest.
     ** OBJECT_SPEC_INVALID - The data source object specification is invalid.
     */
    errorCode: 'DATA_EXECUTION_ERROR_CODE_UNSPECIFIED' | 'TIMED_OUT' | 'TOO_MANY_ROWS' | 'TOO_MANY_CELLS' | 'ENGINE' | 'PARAMETER_INVALID' | 'UNSUPPORTED_DATA_TYPE' | 'DUPLICATE_COLUMN_NAMES' | 'INTERRUPTED' | 'CONCURRENT_QUERY' | 'OTHER' | 'TOO_MANY_CHARS_PER_CELL' | 'DATA_NOT_FOUND' | 'PERMISSION_DENIED' | 'MISSING_COLUMN_ALIAS' | 'OBJECT_NOT_FOUND' | 'OBJECT_IN_ERROR_STATE' | 'OBJECT_SPEC_INVALID';
    /**
     * The error message, which may be empty.
     */
    errorMessage: string;
    /**
     * Gets the time the data last successfully refreshed.
     */
    lastRefreshTime: string;
}
//# sourceMappingURL=DataExecutionStatus.d.ts.map