/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartData } from './ChartData';
import { TextFormat } from './TextFormat';
export interface DataLabel {
    /**
     * The type of the data label.
     ** DATA_LABEL_TYPE_UNSPECIFIED - The data label type is not specified and will be interpreted depending on the context of the data label within the chart.
     ** NONE - The data label is not displayed.
     ** DATA - The data label is displayed using values from the series data.
     ** CUSTOM - The data label is displayed using values from a custom data source indicated by customLabelData.
     */
    type: 'DATA_LABEL_TYPE_UNSPECIFIED' | 'NONE' | 'DATA' | 'CUSTOM';
    /**
     * The text format used for the data label.
     ** DATA_LABEL_PLACEMENT_UNSPECIFIED - The positioning is determined automatically by the renderer.
     ** CENTER - Center within a bar or column, both horizontally and vertically.
     ** LEFT - To the left of a data point.
     ** RIGHT - To the right of a data point.
     ** ABOVE - Above a data point.
     ** BELOW - Below a data point.
     ** INSIDE_END - Inside a bar or column at the end (top if positive, bottom if negative).
     ** INSIDE_BASE - Inside a bar or column at the base.
     ** OUTSIDE_END - Outside a bar or column at the end.
     */
    textFormat: TextFormat;
    /**
     * The placement of the data label relative to the labeled data.
     */
    placement: 'DATA_LABEL_PLACEMENT_UNSPECIFIED' | 'CENTER' | 'LEFT' | 'RIGHT' | 'ABOVE' | 'BELOW' | 'INSIDE_END' | 'INSIDE_BASE' | 'OUTSIDE_END';
    /**
     * Data to use for custom labels. Only used if type is set to CUSTOM . This data must be the same length as the series or other element this data label is applied to. In addition, if the series is split into multiple source ranges, this source data must come from the next column in the source data. For example, if the series is B2:B4,E6:E8 then this data must come from C2:C4,F6:F8.
     */
    customLabelData: ChartData;
}
//# sourceMappingURL=DataLabel.d.ts.map