/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataSourceRefreshDailySchedule } from './DataSourceRefreshDailySchedule';
import { DataSourceRefreshMonthlySchedule } from './DataSourceRefreshMonthlySchedule';
import { DataSourceRefreshWeeklySchedule } from './DataSourceRefreshWeeklySchedule';
import { Interval } from './Interval';
export declare type DataSourceRefreshSchedule = DataSourceRefreshScheduleAsDaily | DataSourceRefreshScheduleAsWeekly | DataSourceRefreshScheduleAsMonthly;
interface DataSourceRefreshScheduleCommons {
    /**
     * True if the refresh schedule is enabled, or false otherwise.
     */
    enabled: boolean;
    /**
     * The scope of the refresh. Must be ALL_DATA_SOURCES.
     ** DATA_SOURCE_REFRESH_SCOPE_UNSPECIFIED - Default value, do not use.
     ** ALL_DATA_SOURCES - Refreshes all data sources and their associated data source objects in the spreadsheet.
     */
    refreshScope: 'DATA_SOURCE_REFRESH_SCOPE_UNSPECIFIED' | 'ALL_DATA_SOURCES';
    /**
     * Output only. The time interval of the next run.
     */
    nextRun: Interval;
}
interface DataSourceRefreshScheduleAsDaily extends DataSourceRefreshScheduleCommons {
    /**
     * Daily refresh schedule.
     */
    dailySchedule: DataSourceRefreshDailySchedule;
}
interface DataSourceRefreshScheduleAsWeekly extends DataSourceRefreshScheduleCommons {
    /**
     * Weekly refresh schedule.
     */
    weeklySchedule: DataSourceRefreshWeeklySchedule;
}
interface DataSourceRefreshScheduleAsMonthly extends DataSourceRefreshScheduleCommons {
    /**
     * Monthly refresh schedule.
     */
    monthlySchedule: DataSourceRefreshMonthlySchedule;
}
export {};
//# sourceMappingURL=DataSourceRefreshSchedule.d.ts.map