/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataExecutionStatus } from './DataExecutionStatus';
import { DataSourceColumnReference } from './DataSourceColumnReference';
import { FilterSpec } from './FilterSpec';
import { SortSpec } from './SortSpec';
export interface DataSourceTable {
    /**
     * The ID of the data source the data source table is associated with.
     */
    dataSourceId: string;
    /**
     * The type to select columns for the data source table. Defaults to SELECTED.
     ** DATA_SOURCE_TABLE_COLUMN_SELECTION_TYPE_UNSPECIFIED - The default column selection type, do not use.
     ** SELECTED - Select columns specified by columns field.
     ** SYNC_ALL - Sync all current and future columns in the data source. If set, the data source table fetches all the columns in the data source at the time of refresh.
     */
    columnSelectionType: 'DATA_SOURCE_TABLE_COLUMN_SELECTION_TYPE_UNSPECIFIED' | 'SELECTED' | 'SYNC_ALL';
    /**
     * Columns selected for the data source table. The columnSelectionType must be SELECTED.
     */
    columns: DataSourceColumnReference[];
    /**
     * Filter specifications in the data source table.
     */
    filterSpecs: FilterSpec[];
    /**
     * Sort specifications in the data source table. The result of the data source table is sorted based on the sort specifications in order.
     */
    sortSpecs: SortSpec[];
    /**
     * The limit of rows to return. If not set, a default limit is applied. Please refer to the Sheets editor for the default and max limit.
     */
    rowLimit: number;
    /**
     * Output only. The data execution status.
     */
    dataExecutionStatus: DataExecutionStatus;
}
//# sourceMappingURL=DataSourceTable.d.ts.map