/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DeveloperMetadataLocation } from './DeveloperMetadataLocation';
export interface DeveloperMetadata {
    /**
     * The spreadsheet-scoped unique ID that identifies the metadata. IDs may be specified when metadata is created, otherwise one will be randomly generated and assigned. Must be positive.
     */
    metadataId: number;
    /**
     * The metadata key. There may be multiple metadata in a spreadsheet with the same key. Developer metadata must always have a key specified.
     */
    metadataKey: string;
    /**
     * Data associated with the metadata's key.
     */
    metadataValue: string;
    /**
     * The location where the metadata is associated.
     */
    location: DeveloperMetadataLocation;
    /**
     * The metadata visibility. Developer metadata must always have a visibility specified.
     ** DEVELOPER_METADATA_VISIBILITY_UNSPECIFIED - Default value.
     ** DOCUMENT - Document-visible metadata is accessible from any developer project with access to the document.
     ** PROJECT - Project-visible metadata is only visible to and accessible by the developer project that created the metadata.
     */
    visibility: 'DEVELOPER_METADATA_VISIBILITY_UNSPECIFIED' | 'DOCUMENT' | 'PROJECT';
}
//# sourceMappingURL=DeveloperMetadata.d.ts.map