/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HistogramSeries } from './HistogramSeries';
export interface HistogramChartSpec {
    /**
     * The series for a histogram may be either a single series of values to be bucketed or multiple series, each of the same length, containing the name of the series followed by the values to be bucketed for that series.
     */
    series: HistogramSeries[];
    /**
     * The position of the chart legend.
     ** HISTOGRAM_CHART_LEGEND_POSITION_UNSPECIFIED - Default value, do not use.
     ** BOTTOM_LEGEND - The legend is rendered on the bottom of the chart.
     ** LEFT_LEGEND - The legend is rendered on the left of the chart.
     ** RIGHT_LEGEND - The legend is rendered on the right of the chart.
     ** TOP_LEGEND - The legend is rendered on the top of the chart.
     ** NO_LEGEND - No legend is rendered.
     ** INSIDE_LEGEND - The legend is rendered inside the chart area.
     */
    legendPosition: 'HISTOGRAM_CHART_LEGEND_POSITION_UNSPECIFIED' | 'BOTTOM_LEGEND' | 'LEFT_LEGEND' | 'RIGHT_LEGEND' | 'TOP_LEGEND' | 'NO_LEGEND' | 'INSIDE_LEGEND';
    /**
     * Whether horizontal divider lines should be displayed between items in each column.
     */
    showItemDividers: boolean;
    /**
     * By default the bucket size (the range of values stacked in a single column) is chosen automatically, but it may be overridden here. E.g., A bucket size of 1.5 results in buckets from 0 - 1.5, 1.5 - 3.0, etc. Cannot be negative. This field is optional.
     */
    bucketSize?: number;
    /**
     * The outlier percentile is used to ensure that outliers do not adversely affect the calculation of bucket sizes. For example, setting an outlier percentile of 0.05 indicates that the top and bottom 5% of values when calculating buckets. The values are still included in the chart, they will be added to the first or last buckets instead of their own buckets. Must be between 0.0 and 0.5.
     */
    outlierPercentile: number;
}
//# sourceMappingURL=HistogramChartSpec.d.ts.map