/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartData } from './ChartData';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
export interface OrgChartSpec {
    /**
     * The size of the org chart nodes.
     ** ORG_CHART_LABEL_SIZE_UNSPECIFIED - Default value, do not use.
     ** SMALL - The small org chart node size.
     ** MEDIUM - The medium org chart node size.
     ** LARGE - The large org chart node size.
     */
    nodeSize: 'ORG_CHART_LABEL_SIZE_UNSPECIFIED' | 'SMALL' | 'MEDIUM' | 'LARGE';
    /**
     * The color of the org chart nodes.
     */
    nodeColor: Color;
    /**
     * The color of the org chart nodes. If nodeColor is also set, this field takes precedence.
     */
    nodeColorStyle: ColorStyle;
    /**
     * The color of the selected org chart nodes.
     */
    selectedNodeColor: Color;
    /**
     * The color of the selected org chart nodes. If selectedNodeColor is also set, this field takes precedence.
     */
    selectedNodeColorStyle: ColorStyle;
    /**
     * The data containing the labels for all the nodes in the chart. Labels must be unique.
     */
    labels: ChartData;
    /**
     * The data containing the label of the parent for the corresponding node. A blank value indicates that the node has no parent and is a top-level node. This field is optional.
     */
    parentLabels?: ChartData;
    /**
     * The data containing the tooltip for the corresponding node. A blank value results in no tooltip being displayed for the node. This field is optional.
     */
    tooltips?: ChartData;
}
//# sourceMappingURL=OrgChartSpec.d.ts.map