/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataSourceColumnReference } from './DataSourceColumnReference';
import { PivotGroupLimit } from './PivotGroupLimit';
import { PivotGroupRule } from './PivotGroupRule';
import { PivotGroupSortValueBucket } from './PivotGroupSortValueBucket';
import { PivotGroupValueMetadata } from './PivotGroupValueMetadata';
export declare type PivotGroup = PivotGroupWithOffset | PivotGroupWithReference;
interface PivotGroupCommons {
    /**
     * True if the pivot table should include the totals for this grouping.
     */
    showTotals: boolean;
    /**
     * Metadata about values in the grouping.
     */
    valueMetadata: PivotGroupValueMetadata[];
    /**
     * The order the values in this group should be sorted.
     ** SORT_ORDER_UNSPECIFIED - Default value, do not use this.
     ** ASCENDING - Sort ascending.
     ** DESCENDING - Sort descending.
     */
    sortOrder: 'SORT_ORDER_UNSPECIFIED' | 'ASCENDING' | 'DESCENDING';
    /**
     * The bucket of the opposite pivot group to sort by. If not specified, sorting is alphabetical by this group's values.
     */
    valueBucket: PivotGroupSortValueBucket;
    /**
     * True if the headings in this pivot group should be repeated. This is only valid for row groupings and is ignored by columns.
     *
     * By default, we minimize repitition of headings by not showing higher level headings where they are the same. For example, even though the third row below corresponds to 'Q1 Mar', 'Q1' is not shown because it is redundant with previous rows. Setting repeatHeadings to true would cause 'Q1' to be repeated for 'Feb' and 'Mar'.
     */
    repeatHeadings: boolean;
    /**
     * The labels to use for the row/column groups which can be customized. For example, in the following pivot table, the row label is Region (which could be renamed to State ) and the column label is Product (which could be renamed Item ). Pivot tables created before December 2017 do not have header labels. If you'd like to add header labels to an existing pivot table, please delete the existing pivot table and then create a new pivot table with same parameters.
     */
    label: string;
    /**
     * The group rule to apply to this row/column group.
     */
    groupRule: PivotGroupRule;
    /**
     * The count limit on rows or columns to apply to this pivot group.
     */
    groupLimit: PivotGroupLimit;
}
interface PivotGroupWithOffset extends PivotGroupCommons {
    /**
     * The column offset of the source range that this grouping is based on.
     *
     * For example, if the source was C10:E15 , a sourceColumnOffset of 0 means this group refers to column C , whereas the offset 1 would refer to column D .
     */
    sourceColumnOffset: number;
}
interface PivotGroupWithReference extends PivotGroupCommons {
    /**
     * The reference to the data source column this grouping is based on.
     */
    dataSourceColumnReference: DataSourceColumnReference;
}
export {};
//# sourceMappingURL=PivotGroup.d.ts.map