/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataExecutionStatus } from './DataExecutionStatus';
import { GridRange } from './GridRange';
import { PivotFilterSpec } from './PivotFilterSpec';
import { PivotGroup } from './PivotGroup';
import { PivotValue } from './PivotValue';
export declare type PivotTable = PivotTableWithRange | PivotTableWithSource;
interface PivotTableCommons {
    /**
     * Each row grouping in the pivot table.
     */
    rows: PivotGroup[];
    /**
     * Each column grouping in the pivot table.
     */
    columns: PivotGroup[];
    /**
     * The filters applied to the source columns before aggregating data for the pivot table.
     *
     * Both criteria and filterSpecs are populated in responses. If both fields are specified in an update request, this field takes precedence.
     */
    filterSpecs: PivotFilterSpec[];
    /**
     * A list of values to include in the pivot table.
     */
    values: PivotValue[];
    /**
     * Whether values should be listed horizontally (as columns) or vertically (as rows).
     ** HORIZONTAL - Values are laid out horizontally (as columns).
     ** VERTICAL - Values are laid out vertically (as rows).
     */
    valueLayout: 'HORIZONTAL' | 'VERTICAL';
    /**
     * Output only. The data execution status for data source pivot tables.
     */
    dataExecutionStatus: DataExecutionStatus;
}
interface PivotTableWithRange extends PivotTableCommons {
    /**
     * The range the pivot table is reading data from.
     */
    source: GridRange;
}
interface PivotTableWithSource extends PivotTableCommons {
    /**
     * The ID of the data source the pivot table is reading data from.
     */
    dataSourceId: string;
}
export {};
//# sourceMappingURL=PivotTable.d.ts.map