/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataSourceColumnReference } from './DataSourceColumnReference';
export declare type PivotValue = PivotValueWithOffset | PivotValueWithFormula | PivotValueWithReference;
interface PivotValueCommone {
    /**
     * A function to summarize the value. If formula is set, the only supported values are SUM and CUSTOM . If sourceColumnOffset is set, then CUSTOM is not supported.
     ** PIVOT_STANDARD_VALUE_FUNCTION_UNSPECIFIED - The default, do not use.
     ** SUM - Corresponds to the SUM function.
     ** COUNTA - Corresponds to the COUNTA function.
     ** COUNT - Corresponds to the COUNT function.
     ** COUNTUNIQUE - Corresponds to the COUNTUNIQUE function.
     ** AVERAGE - Corresponds to the AVERAGE function.
     ** MAX - Corresponds to the MAX function.
     ** MIN - Corresponds to the MIN function.
     ** MEDIAN - Corresponds to the MEDIAN function.
     ** PRODUCT - Corresponds to the PRODUCT function.
     ** STDEV - Corresponds to the STDEV function.
     ** STDEVP - Corresponds to the STDEVP function.
     ** VAR - Corresponds to the VAR function.
     ** VARP - Corresponds to the VARP function.
     ** CUSTOM - Indicates the formula should be used as-is. Only valid if PivotValue.formula was set.
     */
    summarizeFunction: 'PIVOT_STANDARD_VALUE_FUNCTION_UNSPECIFIED' | 'SUM' | 'COUNTA' | 'COUNT' | 'COUNTUNIQUE' | 'AVERAGE' | 'MAX' | 'MIN' | 'MEDIAN' | 'PRODUCT' | 'STDEV' | 'STDEVP' | 'VAR' | 'VARP' | 'CUSTOM';
    /**
     * A name to use for the value.
     */
    name: string;
    /**
     * If specified, indicates that pivot values should be displayed as the result of a calculation with another pivot value. For example, if calculatedDisplayType is specified as PERCENT_OF_GRAND_TOTAL, all the pivot values are displayed as the percentage of the grand total. In the Sheets editor, this is referred to as 'Show As' in the value section of a pivot table.
     ** PIVOT_VALUE_CALCULATED_DISPLAY_TYPE_UNSPECIFIED - Default value, do not use.
     ** PERCENT_OF_ROW_TOTAL - Shows the pivot values as percentage of the row total values.
     ** PERCENT_OF_COLUMN_TOTAL - Shows the pivot values as percentage of the column total values.
     ** PERCENT_OF_GRAND_TOTAL - Shows the pivot values as percentage of the grand total values.
     */
    calculatedDisplayType: 'PIVOT_VALUE_CALCULATED_DISPLAY_TYPE_UNSPECIFIED' | 'PERCENT_OF_ROW_TOTAL' | 'PERCENT_OF_COLUMN_TOTAL' | 'PERCENT_OF_GRAND_TOTAL';
}
interface PivotValueWithOffset extends PivotValueCommone {
    /**
     * The column offset of the source range that this value reads from.
     *
     * For example, if the source was C10:E15, a sourceColumnOffset of 0 means this value refers to column C, whereas the offset 1 would refer to column D.
     */
    sourceColumnOffset: number;
}
interface PivotValueWithFormula extends PivotValueCommone {
    /**
     * A custom formula to calculate the value. The formula must start with an = character.
     */
    formula: string;
}
interface PivotValueWithReference extends PivotValueCommone {
    /**
     * The reference to the data source column that this value reads from.
     */
    dataSourceColumnReference: DataSourceColumnReference;
}
export {};
//# sourceMappingURL=PivotValue.d.ts.map