/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaselineValueFormat } from './BaselineValueFormat';
import { ChartCustomNumberFormatOptions } from './ChartCustomNumberFormatOptions';
import { ChartData } from './ChartData';
import { KeyValueFormat } from './KeyValueFormat';
export interface ScorecardChartSpec {
    /**
     * The data for scorecard key value.
     */
    keyValueData: ChartData;
    /**
     * The data for scorecard baseline value. This field is optional.
     */
    baselineValueData?: ChartData;
    /**
     * The aggregation type for key and baseline chart data in scorecard chart. This field is not supported for data source charts. Use the ChartData.aggregateType field of the keyValueData or baselineValueData instead for data source charts. This field is optional.
     ** CHART_AGGREGATE_TYPE_UNSPECIFIED - Default value, do not use.
     ** AVERAGE - Average aggregate function.
     ** COUNT - Count aggregate function.
     ** MAX - Maximum aggregate function.
     ** MEDIAN - Median aggregate function.
     ** MIN - Minimum aggregate function.
     ** SUM - Sum aggregate function.
     */
    aggregateType?: 'CHART_AGGREGATE_TYPE_UNSPECIFIED' | 'AVERAGE' | 'COUNT' | 'MAX' | 'MEDIAN' | 'MIN' | 'SUM';
    /**
     * Formatting options for key value.
     */
    keyValueFormat: KeyValueFormat;
    /**
     * Formatting options for baseline value. This field is needed only if baselineValueData is specified.
     */
    baselineValueFormat?: BaselineValueFormat;
    /**
     * Value to scale scorecard key and baseline value. For example, a factor of 10 can be used to divide all values in the chart by 10. This field is optional.
     */
    scaleFactor?: number;
    /**
     * The number format source used in the scorecard chart. This field is optional.
     ** CHART_NUMBER_FORMAT_SOURCE_UNDEFINED - Default value, do not use.
     ** FROM_DATA - Inherit number formatting from data.
     ** CUSTOM - Apply custom formatting as specified by ChartCustomNumberFormatOptions.
     */
    numberFormatSource?: 'CHART_NUMBER_FORMAT_SOURCE_UNDEFINED' | 'FROM_DATA' | 'CUSTOM';
    /**
     * Custom formatting options for numeric key/baseline values in scorecard chart. This field is used only when numberFormatSource is set to CUSTOM . This field is optional.
     */
    customFormatOptions?: ChartCustomNumberFormatOptions;
}
//# sourceMappingURL=ScorecardChartSpec.d.ts.map