/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BandedRange } from './BandedRange';
import { BasicFilter } from './BasicFilter';
import { ConditionalFormatRule } from './ConditionalFormatRule';
import { DeveloperMetadata } from './DeveloperMetadata';
import { DimensionGroup } from './DimensionGroup';
import { EmbeddedChart } from './EmbeddedChart';
import { FilterView } from './FilterView';
import { GridData } from './GridData';
import { GridRange } from './GridRange';
import { ProtectedRange } from './ProtectedRange';
import { SheetProperties } from './SheetProperties';
import { Slicer } from './Slicer';
export interface Sheet {
    /**
     * The properties of the sheet.
     */
    properties: SheetProperties;
    /**
     * Data in the grid, if this is a grid sheet.
     *
     * The number of GridData objects returned is dependent on the number of ranges requested on this sheet. For example, if this is representing Sheet1 , and the spreadsheet was requested with ranges Sheet1!A1:C10 and Sheet1!D15:E20 , then the first GridData will have a startRow / startColumn of 0 , while the second one will have startRow 14 (zero-based row 15), and startColumn 3 (zero-based column D).
     *
     * For a DATA_SOURCE sheet, you can not request a specific range, the GridData contains all the values.
     */
    data?: GridData[];
    /**
     * The ranges that are merged together.
     */
    merges?: GridRange[];
    /**
     * The conditional format rules in this sheet.
     */
    conditionalFormats?: ConditionalFormatRule[];
    /**
     * The filter views in this sheet.
     */
    filterViews?: FilterView[];
    /**
     * The protected ranges in this sheet.
     */
    protectedRanges?: ProtectedRange[];
    /**
     * The filter on this sheet, if any.
     */
    basicFilter?: BasicFilter;
    /**
     * The specifications of every chart on this sheet.
     */
    charts?: EmbeddedChart[];
    /**
     * The banded (alternating colors) ranges on this sheet.
     */
    bandedRanges?: BandedRange[];
    /**
     * The developer metadata associated with a sheet.
     */
    developerMetadata?: DeveloperMetadata[];
    /**
     * All row groups on this sheet, ordered by increasing range start index, then by group depth.
     */
    rowGroups?: DimensionGroup[];
    /**
     * All column groups on this sheet, ordered by increasing range start index, then by group depth.
     */
    columnGroups?: DimensionGroup[];
    /**
     * The slicers on this sheet.
     */
    slicers?: Slicer[];
}
//# sourceMappingURL=Sheet.d.ts.map