/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { FilterCriteria } from './FilterCriteria';
import { GridRange } from './GridRange';
import { TextFormat } from './TextFormat';
export interface SlicerSpec {
    /**
     * The data range of the slicer.
     */
    dataRange: GridRange;
    /**
     * The filtering criteria of the slicer.
     */
    filterCriteria: FilterCriteria;
    /**
     * The column index in the data table on which the filter is applied to.
     */
    columnIndex: number;
    /**
     * True if the filter should apply to pivot tables. If not set, default to True .
     */
    applyToPivotTables: boolean;
    /**
     * The title of the slicer.
     */
    title: string;
    /**
     * The text format of title in the slicer.
     */
    textFormat: TextFormat;
    /**
     * The background color of the slicer.
     */
    backgroundColor: Color;
    /**
     * The background color of the slicer. If backgroundColor is also set, this field takes precedence.
     */
    backgroundColorStyle: ColorStyle;
    /**
     * The horizontal alignment of title in the slicer. If unspecified, defaults to LEFT
     ** HORIZONTAL_ALIGN_UNSPECIFIED - The horizontal alignment is not specified. Do not use this.
     ** LEFT - The text is explicitly aligned to the left of the cell.
     ** CENTER - The text is explicitly aligned to the center of the cell.
     ** RIGHT - The text is explicitly aligned to the right of the cell.
     */
    horizontalAlignment: 'HORIZONTAL_ALIGN_UNSPECIFIED' | 'LEFT' | 'CENTER' | 'RIGHT';
}
//# sourceMappingURL=SlicerSpec.d.ts.map