/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { DataSourceColumnReference } from './DataSourceColumnReference';
export declare type SortSpec = SortSpecWithIndex | SortSpecWithReference;
interface SortSpecCommon {
    /**
     * The order data should be sorted.
     ** SORT_ORDER_UNSPECIFIED - Default value, do not use this.
     ** ASCENDING - Sort ascending.
     ** DESCENDING - Sort descending.
     */
    sortOrder: 'SORT_ORDER_UNSPECIFIED' | 'ASCENDING' | 'DESCENDING';
    /**
     * The foreground color to sort by; cells with this foreground color are sorted to the top. Mutually exclusive with backgroundColor.
     */
    foregroundColor: Color;
    /**
     * The foreground color to sort by; cells with this foreground color are sorted to the top. Mutually exclusive with backgroundColor , and must be an RGB-type color. If foregroundColor is also set, this field takes precedence.
     */
    foregroundColorStyle: ColorStyle;
    /**
     * The background fill color to sort by; cells with this fill color are sorted to the top. Mutually exclusive with foregroundColor.
     */
    backgroundColor: Color;
    /**
     * The background fill color to sort by; cells with this fill color are sorted to the top. Mutually exclusive with foregroundColor , and must be an RGB-type color. If backgroundColor is also set, this field takes precedence.
     */
    backgroundColorStyle: ColorStyle;
}
interface SortSpecWithIndex extends SortSpecCommon {
    /**
     * The dimension the sort should be applied to.
     */
    dimensionIndex: number;
}
interface SortSpecWithReference extends SortSpecCommon {
    /**
     * Reference to a data source column.
     */
    dataSourceColumnReference: DataSourceColumnReference;
}
export {};
//# sourceMappingURL=SortSpec.d.ts.map