/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataSource } from './DataSource';
import { DataSourceRefreshSchedule } from './DataSourceRefreshSchedule';
import { DeveloperMetadata } from './DeveloperMetadata';
import { NamedRange } from './NamedRange';
import { Sheet } from './Sheet';
import { CreateSpreadsheetProperties, SpreadsheetProperties } from './SpreadsheetProperties';
export interface Spreadsheet {
    /**
     * The ID of the spreadsheet. This field is read-only.
     */
    spreadsheetId: string;
    /**
     * Overall properties of a spreadsheet.
     */
    properties: SpreadsheetProperties;
    /**
     * The sheets that are part of a spreadsheet.
     */
    sheets: Sheet[];
    /**
     * The named ranges defined in a spreadsheet.
     */
    namedRanges?: NamedRange[];
    /**
     * The url of the spreadsheet. This field is read-only.
     */
    spreadsheetUrl: string;
    /**
     * The developer metadata associated with a spreadsheet.
     */
    developerMetadata?: DeveloperMetadata[];
    /**
     * A list of external data sources connected with the spreadsheet.
     */
    dataSources?: DataSource[];
    /**
     * Output only. A list of data source refresh schedules.
     */
    dataSourceSchedules?: DataSourceRefreshSchedule[];
}
export interface SpreadsheetCreate {
    /**
     * Overall properties of a spreadsheet.
     */
    properties: CreateSpreadsheetProperties;
    /**
     * The sheets that are part of a spreadsheet.
     */
    sheets?: Sheet[];
    /**
     * The named ranges defined in a spreadsheet.
     */
    namedRanges?: NamedRange[];
    /**
     * The developer metadata associated with a spreadsheet.
     */
    developerMetadata?: DeveloperMetadata[];
    /**
     * A list of external data sources connected with the spreadsheet.
     */
    dataSources?: DataSource[];
    /**
     * Output only. A list of data source refresh schedules.
     */
    dataSourceSchedules?: DataSourceRefreshSchedule[];
}
//# sourceMappingURL=Spreadsheet.d.ts.map