/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CellFormat } from './CellFormat';
import { IterativeCalculationSettings } from './IterativeCalculationSettings';
import { SpreadsheetTheme } from './SpreadsheetTheme';
export interface SpreadsheetProperties {
    /**
     * The title of the spreadsheet.
     */
    title: string;
    /**
     * The locale of the spreadsheet in one of the following formats:
     ** an ISO 639-1 language code such as en
     ** an ISO 639-2 language code such as fil, if no 639-1 code exists
     ** a combination of the ISO language code and country code, such as en_US
     *
     * Note: when updating this field, not all locales/languages are supported.
     */
    locale: string;
    /**
     * The amount of time to wait before volatile functions are recalculated.
     ** RECALCULATION_INTERVAL_UNSPECIFIED - Default value. This value must not be used.
     ** ON_CHANGE - Volatile functions are updated on every change.
     ** MINUTE - Volatile functions are updated on every change and every minute.
     ** HOUR - Volatile functions are updated on every change and hourly.
     */
    autoRecalc?: 'RECALCULATION_INTERVAL_UNSPECIFIED' | 'ON_CHANGE' | 'MINUTE' | 'HOUR';
    /**
     * The time zone of the spreadsheet, in CLDR format such as America/New_York. If the time zone isn't recognized, this may be a custom time zone such as GMT-07:00.
     */
    timeZone: string;
    /**
     * The default format of all cells in the spreadsheet. CellData.effectiveFormat will not be set if the cell's format is equal to this default format. This field is read-only.
     */
    defaultFormat: CellFormat;
    /**
     * Determines whether and how circular references are resolved with iterative calculation. Absence of this field means that circular references result in calculation errors.
     */
    iterativeCalculationSettings?: IterativeCalculationSettings;
    /**
     * Theme applied to the spreadsheet.
     */
    spreadsheetTheme: SpreadsheetTheme;
}
export interface CreateSpreadsheetProperties {
    /**
     * The title of the spreadsheet.
     */
    title: string;
    /**
     * The locale of the spreadsheet in one of the following formats:
     ** an ISO 639-1 language code such as en
     ** an ISO 639-2 language code such as fil, if no 639-1 code exists
     ** a combination of the ISO language code and country code, such as en_US
     *
     * Note: when updating this field, not all locales/languages are supported.
     */
    locale?: string;
    /**
     * The amount of time to wait before volatile functions are recalculated.
     ** RECALCULATION_INTERVAL_UNSPECIFIED - Default value. This value must not be used.
     ** ON_CHANGE - Volatile functions are updated on every change.
     ** MINUTE - Volatile functions are updated on every change and every minute.
     ** HOUR - Volatile functions are updated on every change and hourly.
     */
    autoRecalc?: 'RECALCULATION_INTERVAL_UNSPECIFIED' | 'ON_CHANGE' | 'MINUTE' | 'HOUR';
    /**
     * The time zone of the spreadsheet, in CLDR format such as America/New_York. If the time zone isn't recognized, this may be a custom time zone such as GMT-07:00.
     */
    timeZone?: string;
    /**
     * Determines whether and how circular references are resolved with iterative calculation. Absence of this field means that circular references result in calculation errors.
     */
    iterativeCalculationSettings?: IterativeCalculationSettings;
    /**
     * Theme applied to the spreadsheet.
     */
    spreadsheetTheme?: SpreadsheetTheme;
}
//# sourceMappingURL=SpreadsheetProperties.d.ts.map