/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ChartData } from './ChartData';
import { Color } from './Color';
import { ColorStyle } from './ColorStyle';
import { TextFormat } from './TextFormat';
import { TreemapChartColorScale } from './TreemapChartColorScale';
export interface TreemapChartSpec {
    /**
     * The data that contains the treemap cell labels.
     */
    labels: ChartData;
    /**
     * The data the contains the treemap cells' parent labels.
     */
    parentLabels: ChartData;
    /**
     * The data that determines the size of each treemap data cell. This data is expected to be numeric. The cells corresponding to non-numeric or missing data will not be rendered. If colorData is not specified, this data is used to determine data cell background colors as well.
     */
    sizeData: ChartData;
    /**
     * The data that determines the background color of each treemap data cell. This field is optional. If not specified, sizeData is used to determine background colors. If specified, the data is expected to be numeric. colorScale will determine how the values in this data map to data cell background colors.
     */
    colorData?: ChartData;
    /**
     * The text format for all labels on the chart.
     */
    textFormat: TextFormat;
    /**
     * The number of data levels to show on the treemap chart. These levels are interactive and are shown with their labels. Defaults to 2 if not specified.
     */
    levels: number;
    /**
     * The number of additional data levels beyond the labeled levels to be shown on the treemap chart. These levels are not interactive and are shown without their labels. Defaults to 0 if not specified.
     */
    hintedLevels: number;
    /**
     * The minimum possible data value. Cells with values less than this will have the same color as cells with this value. If not specified, defaults to the actual minimum value from colorData , or the minimum value from sizeData if colorData is not specified.
     */
    minValue: number;
    /**
     * The maximum possible data value. Cells with values greater than this will have the same color as cells with this value. If not specified, defaults to the actual maximum value from colorData , or the maximum value from sizeData if colorData is not specified.
     */
    maxValue: number;
    /**
     * The background color for header cells.
     */
    headerColor: Color;
    /**
     * The background color for header cells. If headerColor is also set, this field takes precedence.
     */
    headerColorStyle: ColorStyle;
    /**
     * The color scale for data cells in the treemap chart. Data cells are assigned colors based on their color values. These color values come from colorData , or from sizeData if colorData is not specified. Cells with color values less than or equal to minValue will have minValueColor as their background color. Cells with color values greater than or equal to maxValue will have maxValueColor as their background color. Cells with color values between minValue and maxValue will have background colors on a gradient between minValueColor and maxValueColor , the midpoint of the gradient being midValueColor . Cells with missing or non-numeric color values will have noDataColor as their background color.
     */
    colorScale: TreemapChartColorScale;
    /**
     * True to hide tooltips.
     */
    hideTooltips: boolean;
}
//# sourceMappingURL=TreemapChartSpec.d.ts.map