/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
export interface ValueRange {
    /**
     * The range the values cover, in A1 notation. For output, this range indicates the entire requested range, even though the values will exclude trailing rows and columns. When appending values, this field represents the range to search for a table, after which values will be appended.
     */
    range?: string;
    /**
     * The major dimension of the values.
     *
     * For output, if the spreadsheet data is: A1=1,B1=2,A2=3,B2=4, then requesting range=A1:B2,majorDimension=ROWS will return [[1,2],[3,4]], whereas requesting range=A1:B2,majorDimension=COLUMNS will return [[1,3],[2,4]].
     *
     * For input, with range=A1:B2,majorDimension=ROWS then [[1,2],[3,4]] will set A1=1,B1=2,A2=3,B2=4. With range=A1:B2,majorDimension=COLUMNS then [[1,2],[3,4]] will set A1=1,B1=3,A2=2,B2=4.
     *
     * When writing, if this field is not set, it defaults to ROWS.
     ** ROWS - Operates on the rows of a sheet.
     ** COLUMNS - Operates on the columns of a sheet.
     */
    majorDimension?: 'ROWS' | 'COLUMNS';
    /**
     * The data that was read or to be written. This is an array of arrays, the outer array representing all the data and each inner array representing a major dimension. Each item in the inner array corresponds with one cell.
     *
     * For output, empty trailing rows and columns will not be included.
     *
     * For input, supported value types are: bool, string, and double. Null values will be skipped. To set a cell to an empty value, set the string value to an empty string.
     */
    values: any[][];
}
//# sourceMappingURL=ValueRange.d.ts.map