/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { DataLabel } from './DataLabel';
import { LineStyle } from './LineStyle';
import { WaterfallChartDomain } from './WaterfallChartDomain';
import { WaterfallChartSeries } from './WaterfallChartSeries';
export interface WaterfallChartSpec {
    /**
     * The domain data (horizontal axis) for the waterfall chart.
     */
    domain: WaterfallChartDomain;
    /**
     * The data this waterfall chart is visualizing.
     */
    series: WaterfallChartSeries[];
    /**
     * The stacked type.
     ** WATERFALL_STACKED_TYPE_UNSPECIFIED - Default value, do not use.
     ** STACKED - Values corresponding to the same domain (horizontal axis) value will be stacked vertically.
     ** SEQUENTIAL - Series will spread out along the horizontal axis.
     */
    stackedType: 'WATERFALL_STACKED_TYPE_UNSPECIFIED' | 'STACKED' | 'SEQUENTIAL';
    /**
     * True to interpret the first value as a total.
     */
    firstValueIsTotal: boolean;
    /**
     * True to hide connector lines between columns.
     */
    hideConnectorLines: boolean;
    /**
     * The line style for the connector lines.
     */
    connectorLineStyle: LineStyle;
    /**
     * Controls whether to display additional data labels on stacked charts which sum the total value of all stacked values at each value along the domain axis. stackedType must be STACKED and neither CUSTOM nor placement can be set on the totalDataLabel .
     */
    totalDataLabel: DataLabel;
}
//# sourceMappingURL=WaterfallChartSpec.d.ts.map