/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { HeadersOption } from '@managed-api/commons-core';
import { DataSource } from '../definitions/DataSource';
import { DataSourceRefreshSchedule } from '../definitions/DataSourceRefreshSchedule';
import { DeveloperMetadata } from '../definitions/DeveloperMetadata';
import { NamedRange } from '../definitions/NamedRange';
import { Sheet } from '../definitions/Sheet';
import { Spreadsheet } from '../definitions/Spreadsheet';
import { CreateSpreadsheetProperties } from '../definitions/SpreadsheetProperties';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface CreateSpreadsheetRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * Overall properties of a spreadsheet.
         */
        properties: CreateSpreadsheetProperties;
        /**
         * The sheets that are part of a spreadsheet.
         */
        sheets?: Sheet[];
        /**
         * The named ranges defined in a spreadsheet.
         */
        namedRanges?: NamedRange[];
        /**
         * The developer metadata associated with a spreadsheet.
         */
        developerMetadata?: DeveloperMetadata[];
        /**
         * A list of external data sources connected with the spreadsheet.
         */
        dataSources?: DataSource[];
        /**
         * Output only. A list of data source refresh schedules.
         */
        dataSourceSchedules?: DataSourceRefreshSchedule[];
    };
}
export interface CreateSpreadsheetResponseOK extends Spreadsheet {
}
export interface CreateSpreadsheetResponseError extends CommonError {
}
export interface GetSpreadsheetRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The spreadsheet to request.
     */
    spreadsheetId: string;
    /**
     * The ranges to retrieve from the spreadsheet.
     */
    ranges?: string[];
    /**
     * True if grid data should be returned. This parameter is ignored if a field mask was set in the request.
     */
    includeGridData?: boolean;
}
export interface GetSpreadsheetResponseOK extends Spreadsheet {
}
export interface GetSpreadsheetResponseError extends CommonError {
}
//# sourceMappingURL=spreadsheet.d.ts.map